#!/usr/bin/python3

import pytest
from influxdb import InfluxDBClient

@pytest.mark.parametrize("service_name", [
    ('clmc-service'),
    ('apache'),
    ('nginx'),
    ('mongo'),
    ('ffmpeg'),
    ('host'),
    ])
def test_service_name(telegraf_agent_config, service_name):
    assert any(s['name'] == service_name for s in telegraf_agent_config['hosts']), "{0} not in list of hosts".format(service_name)
    
def test_ping(telegraf_agent_config):
    """This test will only run on linux as the process call is not portable, there's a better way"""
    for host in telegraf_agent_config['hosts']:
        response = os.system("ping -c 1 " + host['ip_address'])
        assert response == 0, "Could not ping {0} on ip address {1}".format(host['name'], host['ip_address'])

@pytest.mark.parametrize("measurement, query, expected_result", [
    ('nginx', 'SELECT mean("requests") AS "mean" FROM "CLMCMetrics"."autogen"."nginx"', 0),
    ('cpu', 'SELECT mean("usage_idle") AS "mean" FROM "CLMCMetrics"."autogen"."cpu"', 0),
    ('mongodb', 'SELECT mean("net_in_bytes") AS "mean" FROM "CLMCMetrics"."autogen"."mongodb"', 0),
    ('net', 'SELECT mean("bytes_sent") AS "mean" FROM "CLMCMetrics"."autogen"."net"', 0),
    ('disk', 'SELECT mean("free") AS "mean" FROM "CLMCMetrics"."autogen"."disk"', 0),
    ('diskio', 'SELECT mean("write_bytes") AS "mean" FROM "CLMCMetrics"."autogen"."diskio"', 0),
    ('mem', 'SELECT mean("free") AS "mean" FROM "CLMCMetrics"."autogen"."mem"', 0)              
    ])
def test_all_inputs(influxdb, measurement, query, expected_result):
    """
    Tests measurements are received from an input plugin aggregated across all services

    :param influxdb: the influx db client fixture
    :param measurement: the measurement to test
    :param query: the query to execute
    :param expected_result: the expected result from the query
    """

    query_result = influxdb.query('SHOW measurements ON "CLMCMetrics"')
    points = list(query_result.get_points())
    assert any(p['name'] == measurement for p in points), "{0} not in measurement list".format(measurement)
    
    query_result = influxdb.query(query)
    points = next(query_result.get_points())  # get_points() returns a generator, to take the first element we can use the next() function
    actual_result = points['mean']
    assert actual_result > expected_result, "actual result {0} is not > expected result {1} for query {2}".format(actual_result, str(expected_result), query)


@pytest.mark.parametrize("query, expected_result", 
    [('filter query', 0),
     ('filter query', 0),
     ('filter query', 0)
    ])
def test_global_tag_filtering(influxdb, query, expected_result):
    """Tests that the global tags are inserted correctly into the global configuration using the install CLMC script
    """
    # run query
    # check result
    assert 1
